package cn.iocoder.yudao.module.dms.controller.admin.checktaskitem;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktaskitem.vo.DmsCheckTaskItemPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktaskitem.vo.DmsCheckTaskItemRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktaskitem.vo.DmsCheckTaskItemSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktaskitem.DmsCheckTaskItemDO;
import cn.iocoder.yudao.module.dms.service.checktaskitem.DmsCheckTaskItemService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 点巡检任务检查项")
@RestController
@RequestMapping("/dms/check-task-item")
@Validated
public class DmsCheckTaskItemController {

    @Resource
    private DmsCheckTaskItemService checkTaskItemService;

    @PostMapping("/create")
    @Operation(summary = "创建点巡检任务检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:create')")
    public CommonResult<Long> createCheckTaskItem(@Valid @RequestBody DmsCheckTaskItemSaveReqVO createReqVO) {
        return success(checkTaskItemService.createCheckTaskItem(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新点巡检任务检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:update')")
    public CommonResult<Boolean> updateCheckTaskItem(@Valid @RequestBody DmsCheckTaskItemSaveReqVO updateReqVO) {
        checkTaskItemService.updateCheckTaskItem(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除点巡检任务检查项")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:delete')")
    public CommonResult<Boolean> deleteCheckTaskItem(@RequestParam("id") Long id) {
        checkTaskItemService.deleteCheckTaskItem(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得点巡检任务检查项")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:query')")
    public CommonResult<DmsCheckTaskItemRespVO> getCheckTaskItem(@RequestParam("id") Long id) {
        DmsCheckTaskItemDO checkTaskItem = checkTaskItemService.getCheckTaskItem(id);
        return success(BeanUtils.toBean(checkTaskItem, DmsCheckTaskItemRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得点巡检任务检查项分页")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:query')")
    public CommonResult<PageResult<DmsCheckTaskItemRespVO>> getCheckTaskItemPage(@Valid DmsCheckTaskItemPageReqVO pageReqVO) {
        PageResult<DmsCheckTaskItemDO> pageResult = checkTaskItemService.getCheckTaskItemPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DmsCheckTaskItemRespVO.class));
    }

    @GetMapping("/list")
    @Operation(summary = "获得点巡检任务检查项分页")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:query')")
    public CommonResult<List<DmsCheckTaskItemRespVO>> getCheckTaskItemList(@Valid DmsCheckTaskItemPageReqVO pageReqVO) {
        return success(BeanUtils.toBean(checkTaskItemService.getCheckTaskItemList(pageReqVO), DmsCheckTaskItemRespVO.class));
    }


    @GetMapping("/export-excel")
    @Operation(summary = "导出点巡检任务检查项 Excel")
    @PreAuthorize("@ss.hasPermission('dms:check-task-item:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportCheckTaskItemExcel(@Valid DmsCheckTaskItemPageReqVO pageReqVO,
                                         HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DmsCheckTaskItemDO> list = checkTaskItemService.getCheckTaskItemPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "点巡检任务检查项.xls", "数据", DmsCheckTaskItemRespVO.class,
                BeanUtils.toBean(list, DmsCheckTaskItemRespVO.class));
    }



}
