package cn.iocoder.yudao.module.dms.controller.admin.checktemplate;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplatePageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplateRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplateSaveReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemPageReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplate.DmsCheckTemplateDO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateitem.DmsCheckTemplateItemDO;
import cn.iocoder.yudao.module.dms.service.checktemplate.DmsCheckTemplateService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 点巡检模板")
@RestController
@RequestMapping("/dms/check-template")
@Validated
public class DmsCheckTemplateController {

    @Resource
    private DmsCheckTemplateService checkTemplateService;

    @PostMapping("/create")
    @Operation(summary = "创建点巡检模板")
    @PreAuthorize("@ss.hasPermission('dms:check-template:create')")
    public CommonResult<Long> createCheckTemplate(@Valid @RequestBody DmsCheckTemplateSaveReqVO createReqVO) {
        return success(checkTemplateService.createCheckTemplate(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新点巡检模板")
    @PreAuthorize("@ss.hasPermission('dms:check-template:update')")
    public CommonResult<Boolean> updateCheckTemplate(@Valid @RequestBody DmsCheckTemplateSaveReqVO updateReqVO) {
        checkTemplateService.updateCheckTemplate(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除点巡检模板")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:check-template:delete')")
    public CommonResult<Boolean> deleteCheckTemplate(@RequestParam("id") Long id) {
        checkTemplateService.deleteCheckTemplate(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得点巡检模板")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:check-template:query')")
    public CommonResult<DmsCheckTemplateRespVO> getCheckTemplate(@RequestParam("id") Long id) {
        DmsCheckTemplateDO checkTemplate = checkTemplateService.getCheckTemplate(id);
        return success(BeanUtils.toBean(checkTemplate, DmsCheckTemplateRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得点巡检模板分页")
    @PreAuthorize("@ss.hasPermission('dms:check-template:query')")
    public CommonResult<PageResult<DmsCheckTemplateRespVO>> getCheckTemplatePage(@Valid DmsCheckTemplatePageReqVO pageReqVO) {
        PageResult<DmsCheckTemplateDO> pageResult = checkTemplateService.getCheckTemplatePage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DmsCheckTemplateRespVO.class));
    }

    @GetMapping("/list")
    @Operation(summary = "获得点巡检模板列表")
    @PreAuthorize("@ss.hasPermission('dms:check-template:query')")
    public CommonResult<List<DmsCheckTemplateRespVO>> getCheckTemplateList(@Valid DmsCheckTemplatePageReqVO pageReqVO) {
        List<DmsCheckTemplateDO> listResult = checkTemplateService.getCheckTemplateList(pageReqVO);
        return success(BeanUtils.toBean(listResult,DmsCheckTemplateRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出点巡检模板 Excel")
    @PreAuthorize("@ss.hasPermission('dms:check-template:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportCheckTemplateExcel(@Valid DmsCheckTemplatePageReqVO pageReqVO,
                                         HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DmsCheckTemplateDO> list = checkTemplateService.getCheckTemplatePage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "点巡检模板.xls", "数据", DmsCheckTemplateRespVO.class,
                BeanUtils.toBean(list, DmsCheckTemplateRespVO.class));
    }

    // ==================== 子表（点巡检模板检查项） ====================

    @GetMapping("/check-template-item/page")
    @Operation(summary = "获得点巡检模板检查项分页")
    @Parameter(name = "checkTemplateId", description = "点巡检模板ID")
    @PreAuthorize("@ss.hasPermission('dms:check-template:query')")
    public CommonResult<PageResult<DmsCheckTemplateItemDO>> getCheckTemplateItemPage(DmsCheckTemplateItemPageReqVO pageReqVO) {
        return success(checkTemplateService.getCheckTemplateItemPage(pageReqVO));
    }

    @PostMapping("/check-template-item/create")
    @Operation(summary = "创建点巡检模板检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-template:create')")
    public CommonResult<Long> createCheckTemplateItem(@Valid @RequestBody DmsCheckTemplateItemDO checkTemplateItem) {
        return success(checkTemplateService.createCheckTemplateItem(checkTemplateItem));
    }

    @PutMapping("/check-template-item/update")
    @Operation(summary = "更新点巡检模板检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-template:update')")
    public CommonResult<Boolean> updateCheckTemplateItem(@Valid @RequestBody DmsCheckTemplateItemDO checkTemplateItem) {
        checkTemplateService.updateCheckTemplateItem(checkTemplateItem);
        return success(true);
    }

    @DeleteMapping("/check-template-item/delete")
    @Parameter(name = "id", description = "编号", required = true)
    @Operation(summary = "删除点巡检模板检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-template:delete')")
    public CommonResult<Boolean> deleteCheckTemplateItem(@RequestParam("id") Long id) {
        checkTemplateService.deleteCheckTemplateItem(id);
        return success(true);
    }

    @GetMapping("/check-template-item/get")
    @Operation(summary = "获得点巡检模板检查项")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:check-template:query')")
    public CommonResult<DmsCheckTemplateItemDO> getCheckTemplateItem(@RequestParam("id") Long id) {
        return success(checkTemplateService.getCheckTemplateItem(id));
    }

}