package cn.iocoder.yudao.module.dms.controller.admin.checktemplateclassify;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateclassify.vo.DmsCheckTemplateClassifyListReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateclassify.vo.DmsCheckTemplateClassifyRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateclassify.vo.DmsCheckTemplateClassifySaveReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateclassify.vo.DmsSimpleCheckTemplateClassifyRespVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateclassify.DmsCheckTemplateClassifyDO;
import cn.iocoder.yudao.module.dms.service.checktemplateclassify.DmsCheckTemplateClassifyService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 点巡检模板分类")
@RestController
@RequestMapping("/dms/check-template-classify")
@Validated
public class DmsCheckTemplateClassifyController {

    @Resource
    private DmsCheckTemplateClassifyService checkTemplateClassifyService;

    @PostMapping("/create")
    @Operation(summary = "创建点巡检模板分类")
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:create')")
    public CommonResult<Long> createCheckTemplateClassify(@Valid @RequestBody DmsCheckTemplateClassifySaveReqVO createReqVO) {
        return success(checkTemplateClassifyService.createCheckTemplateClassify(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新点巡检模板分类")
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:update')")
    public CommonResult<Boolean> updateCheckTemplateClassify(@Valid @RequestBody DmsCheckTemplateClassifySaveReqVO updateReqVO) {
        checkTemplateClassifyService.updateCheckTemplateClassify(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除点巡检模板分类")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:delete')")
    public CommonResult<Boolean> deleteCheckTemplateClassify(@RequestParam("id") Long id) {
        checkTemplateClassifyService.deleteCheckTemplateClassify(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得点巡检模板分类")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:query')")
    public CommonResult<DmsCheckTemplateClassifyRespVO> getCheckTemplateClassify(@RequestParam("id") Long id) {
        DmsCheckTemplateClassifyDO checkTemplateClassify = checkTemplateClassifyService.getCheckTemplateClassify(id);
        return success(BeanUtils.toBean(checkTemplateClassify, DmsCheckTemplateClassifyRespVO.class));
    }

    @GetMapping("/list")
    @Operation(summary = "获得点巡检模板分类列表")
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:query')")
    public CommonResult<List<DmsCheckTemplateClassifyRespVO>> getCheckTemplateClassifyList(@Valid DmsCheckTemplateClassifyListReqVO listReqVO) {
        List<DmsCheckTemplateClassifyDO> list = checkTemplateClassifyService.getCheckTemplateClassifyList(listReqVO);
        return success(BeanUtils.toBean(list, DmsCheckTemplateClassifyRespVO.class));
    }

    @GetMapping("/simple-list")
    @Operation(summary = "获得点巡检模板分类精简列表", description = "主要用于前端的下拉选项")
    public CommonResult<List<DmsSimpleCheckTemplateClassifyRespVO>> getSimpleDeviceClassifyList() {
        List<DmsCheckTemplateClassifyDO> list = checkTemplateClassifyService.getSimpleCheckTemplateClassifyList();
        return success(BeanUtils.toBean(list, DmsSimpleCheckTemplateClassifyRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出点巡检模板分类 Excel")
    @PreAuthorize("@ss.hasPermission('dms:check-template-classify:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportCheckTemplateClassifyExcel(@Valid DmsCheckTemplateClassifyListReqVO listReqVO,
                                                 HttpServletResponse response) throws IOException {
        List<DmsCheckTemplateClassifyDO> list = checkTemplateClassifyService.getCheckTemplateClassifyList(listReqVO);
        // 导出 Excel
        ExcelUtils.write(response, "点巡检模板分类.xls", "数据", DmsCheckTemplateClassifyRespVO.class,
                BeanUtils.toBean(list, DmsCheckTemplateClassifyRespVO.class));
    }

}
