package cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateitem.DmsCheckTemplateItemDO;
import cn.iocoder.yudao.module.dms.service.checktemplateitem.DmsCheckTemplateItemService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 点巡检模板检查项")
@RestController
@RequestMapping("/dms/check-template-item")
@Validated
public class DmsCheckTemplateItemController {

    @Resource
    private DmsCheckTemplateItemService checkTemplateItemService;

    @PostMapping("/create")
    @Operation(summary = "创建点巡检模板检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:create')")
    public CommonResult<Long> createCheckTemplateItem(@Valid @RequestBody DmsCheckTemplateItemSaveReqVO createReqVO) {
        return success(checkTemplateItemService.createCheckTemplateItem(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新点巡检模板检查项")
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:update')")
    public CommonResult<Boolean> updateCheckTemplateItem(@Valid @RequestBody DmsCheckTemplateItemSaveReqVO updateReqVO) {
        checkTemplateItemService.updateCheckTemplateItem(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除点巡检模板检查项")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:delete')")
    public CommonResult<Boolean> deleteCheckTemplateItem(@RequestParam("id") Long id) {
        checkTemplateItemService.deleteCheckTemplateItem(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得点巡检模板检查项")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:query')")
    public CommonResult<DmsCheckTemplateItemRespVO> getCheckTemplateItem(@RequestParam("id") Long id) {
        DmsCheckTemplateItemDO checkTemplateItem = checkTemplateItemService.getCheckTemplateItem(id);
        return success(BeanUtils.toBean(checkTemplateItem, DmsCheckTemplateItemRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得点巡检模板检查项分页")
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:query')")
    public CommonResult<PageResult<DmsCheckTemplateItemRespVO>> getCheckTemplateItemPage(@Valid DmsCheckTemplateItemPageReqVO pageReqVO) {
        PageResult<DmsCheckTemplateItemDO> pageResult = checkTemplateItemService.getCheckTemplateItemPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DmsCheckTemplateItemRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出点巡检模板检查项 Excel")
    @PreAuthorize("@ss.hasPermission('dms:check-template-item:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportCheckTemplateItemExcel(@Valid DmsCheckTemplateItemPageReqVO pageReqVO,
                                             HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DmsCheckTemplateItemDO> list = checkTemplateItemService.getCheckTemplateItemPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "点巡检模板检查项.xls", "数据", DmsCheckTemplateItemRespVO.class,
                BeanUtils.toBean(list, DmsCheckTemplateItemRespVO.class));
    }

}