package cn.iocoder.yudao.module.dms.controller.admin.deviceattribute;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.deviceattribute.vo.DmsDeviceAttributePageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.deviceattribute.vo.DmsDeviceAttributeRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.deviceattribute.vo.DmsDeviceAttributeSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.deviceattribute.DmsDeviceAttributeDO;
import cn.iocoder.yudao.module.dms.service.deviceattribute.DmsDeviceAttributeService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 设备属性")
@RestController
@RequestMapping("/dms/device-attribute")
@Validated
public class DmsDeviceAttributeController {

    @Resource
    private DmsDeviceAttributeService deviceAttributeService;

    @PostMapping("/create")
    @Operation(summary = "创建设备属性")
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:create')")
    public CommonResult<Long> createDeviceAttribute(@Valid @RequestBody DmsDeviceAttributeSaveReqVO createReqVO) {
        return success(deviceAttributeService.createDeviceAttribute(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新设备属性")
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:update')")
    public CommonResult<Boolean> updateDeviceAttribute(@Valid @RequestBody DmsDeviceAttributeSaveReqVO updateReqVO) {
        deviceAttributeService.updateDeviceAttribute(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除设备属性")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:delete')")
    public CommonResult<Boolean> deleteDeviceAttribute(@RequestParam("id") Long id) {
        deviceAttributeService.deleteDeviceAttribute(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得设备属性")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:query')")
    public CommonResult<DmsDeviceAttributeRespVO> getDeviceAttribute(@RequestParam("id") Long id) {
        DmsDeviceAttributeDO deviceAttribute = deviceAttributeService.getDeviceAttribute(id);
        return success(BeanUtils.toBean(deviceAttribute, DmsDeviceAttributeRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得设备属性分页")
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:query')")
    public CommonResult<PageResult<DmsDeviceAttributeRespVO>> getDeviceAttributePage(@Valid DmsDeviceAttributePageReqVO pageReqVO) {
        PageResult<DmsDeviceAttributeDO> pageResult = deviceAttributeService.getDeviceAttributePage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DmsDeviceAttributeRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出设备属性 Excel")
    @PreAuthorize("@ss.hasPermission('dms:device-attribute:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportDeviceAttributeExcel(@Valid DmsDeviceAttributePageReqVO pageReqVO,
                                           HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DmsDeviceAttributeDO> list = deviceAttributeService.getDeviceAttributePage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "设备属性.xls", "数据", DmsDeviceAttributeRespVO.class,
                BeanUtils.toBean(list, DmsDeviceAttributeRespVO.class));
    }

}
