package cn.iocoder.yudao.module.dms.controller.admin.devicerepair;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.dms.controller.admin.devicerepair.vo.DmsDeviceRepairPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.devicerepair.vo.DmsDeviceRepairRespVO;
import cn.iocoder.yudao.module.dms.controller.admin.devicerepair.vo.DmsDeviceRepairSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.devicerepair.DmsDeviceRepairDO;
import cn.iocoder.yudao.module.dms.service.devicerepair.DmsDeviceRepairService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 设备报修")
@RestController
@RequestMapping("/dms/device-repair")
@Validated
public class DmsDeviceRepairController {

    @Resource
    private DmsDeviceRepairService deviceRepairService;

    @PostMapping("/create")
    @Operation(summary = "创建设备报修")
    @PreAuthorize("@ss.hasPermission('dms:device-repair:create')")
    public CommonResult<Long> createDeviceRepair(@Valid @RequestBody DmsDeviceRepairSaveReqVO createReqVO) {
        return success(deviceRepairService.createDeviceRepair(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新设备报修")
    @PreAuthorize("@ss.hasPermission('dms:device-repair:update')")
    public CommonResult<Boolean> updateDeviceRepair(@Valid @RequestBody DmsDeviceRepairSaveReqVO updateReqVO) {
        deviceRepairService.updateDeviceRepair(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除设备报修")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('dms:device-repair:delete')")
    public CommonResult<Boolean> deleteDeviceRepair(@RequestParam("id") Long id) {
        deviceRepairService.deleteDeviceRepair(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得设备报修")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('dms:device-repair:query')")
    public CommonResult<DmsDeviceRepairRespVO> getDeviceRepair(@RequestParam("id") Long id) {
        DmsDeviceRepairDO deviceRepair = deviceRepairService.getDeviceRepair(id);
        return success(BeanUtils.toBean(deviceRepair, DmsDeviceRepairRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得设备报修分页")
    @PreAuthorize("@ss.hasPermission('dms:device-repair:query')")
    public CommonResult<PageResult<DmsDeviceRepairRespVO>> getDeviceRepairPage(@Valid DmsDeviceRepairPageReqVO pageReqVO) {
        PageResult<DmsDeviceRepairDO> pageResult = deviceRepairService.getDeviceRepairPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DmsDeviceRepairRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出设备报修 Excel")
    @PreAuthorize("@ss.hasPermission('dms:device-repair:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportDeviceRepairExcel(@Valid DmsDeviceRepairPageReqVO pageReqVO,
                                        HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DmsDeviceRepairDO> list = deviceRepairService.getDeviceRepairPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "设备报修.xls", "数据", DmsDeviceRepairRespVO.class,
                BeanUtils.toBean(list, DmsDeviceRepairRespVO.class));
    }

}
