package cn.iocoder.yudao.module.dms.service.checktask;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.dms.controller.admin.checktask.vo.DmsCheckTaskPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktask.vo.DmsCheckTaskSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktask.DmsCheckTaskDO;

import javax.validation.Valid;
import java.util.Map;

/**
 * 点巡检任务 Service 接口
 *
 * @author dzx
 */
public interface DmsCheckTaskService {

    /**
     * 创建点巡检任务
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createCheckTask(@Valid DmsCheckTaskSaveReqVO createReqVO);

    /**
     * 更新点巡检任务
     *
     * @param updateReqVO 更新信息
     */
    void updateCheckTask(@Valid DmsCheckTaskSaveReqVO updateReqVO);

    /**
     * 删除点巡检任务
     *
     * @param id 编号
     */
    void deleteCheckTask(Long id);

    /**
     * 获得点巡检任务
     *
     * @param id 编号
     * @return 点巡检任务
     */
    DmsCheckTaskDO getCheckTask(Long id);

    /**
     * 获得点巡检任务分页
     *
     * @param pageReqVO 分页查询
     * @return 点巡检任务分页
     */
    PageResult<DmsCheckTaskDO> getCheckTaskPage(DmsCheckTaskPageReqVO pageReqVO);

    /**
     * 统计任务数量
     *
     * @return
     */
    Map<String, Object> tasks();

    /**
     * 任务暂存
     * @param checkTask
     * @return
     */
    String tmpSave(DmsCheckTaskDO checkTask);

    /**
     * 任务提交
     * @param checkTask
     * @return
     */
    String commit(DmsCheckTaskDO checkTask);

    /**
     * 统计当前用户未完成任务数量
     * @param checkTask
     * @return
     */
    Long countCur(DmsCheckTaskDO checkTask);

    /**
     * 获取第一个（最早的）任务
     * @param pageReqVO
     * @return
     */
    DmsCheckTaskDO getFirst(DmsCheckTaskPageReqVO pageReqVO);

}
