package cn.iocoder.yudao.module.dms.service.checktaskitem;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktaskitem.vo.DmsCheckTaskItemPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktaskitem.vo.DmsCheckTaskItemSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktaskitem.DmsCheckTaskItemDO;
import cn.iocoder.yudao.module.dms.dal.pgsql.checktaskitem.DmsCheckTaskItemMapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.dms.enums.ErrorCodeConstants.CHECK_TASK_ITEM_NOT_EXISTS;

/**
 * 点巡检任务检查项 Service 实现类
 *
 * @author dzx
 */
@Service
@Validated
public class DmsCheckTaskItemServiceImpl extends ServiceImpl<DmsCheckTaskItemMapper, DmsCheckTaskItemDO> implements DmsCheckTaskItemService {

    @Resource
    private DmsCheckTaskItemMapper checkTaskItemMapper;

    @Override
    public Long createCheckTaskItem(DmsCheckTaskItemSaveReqVO createReqVO) {
        // 插入
        DmsCheckTaskItemDO checkTaskItem = BeanUtils.toBean(createReqVO, DmsCheckTaskItemDO.class);
        checkTaskItemMapper.insert(checkTaskItem);
        // 返回
        return checkTaskItem.getId();
    }

    @Override
    public void updateCheckTaskItem(DmsCheckTaskItemSaveReqVO updateReqVO) {
        // 校验存在
        validateCheckTaskItemExists(updateReqVO.getId());
        // 更新
        DmsCheckTaskItemDO updateObj = BeanUtils.toBean(updateReqVO, DmsCheckTaskItemDO.class);
        checkTaskItemMapper.updateById(updateObj);
    }

    @Override
    public void deleteCheckTaskItem(Long id) {
        // 校验存在
        validateCheckTaskItemExists(id);
        // 删除
        checkTaskItemMapper.deleteById(id);
    }

    private void validateCheckTaskItemExists(Long id) {
        if (checkTaskItemMapper.selectById(id) == null) {
            throw exception(CHECK_TASK_ITEM_NOT_EXISTS);
        }
    }

    @Override
    public DmsCheckTaskItemDO getCheckTaskItem(Long id) {
        return checkTaskItemMapper.selectById(id);
    }

    @Override
    public PageResult<DmsCheckTaskItemDO> getCheckTaskItemPage(DmsCheckTaskItemPageReqVO pageReqVO) {
        return checkTaskItemMapper.selectPage(pageReqVO);
    }

    @Override
    public List<DmsCheckTaskItemDO> getCheckTaskItemList(DmsCheckTaskItemPageReqVO pageReqVO) {
        return checkTaskItemMapper.selectList(pageReqVO);
    }

}
