package cn.iocoder.yudao.module.dms.service.checktemplate;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplatePageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplateSaveReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemPageReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplate.DmsCheckTemplateDO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateitem.DmsCheckTemplateItemDO;

import javax.validation.Valid;
import java.util.List;

/**
 * 点巡检模板 Service 接口
 *
 * @author dzx
 */
public interface DmsCheckTemplateService {

    /**
     * 创建点巡检模板
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createCheckTemplate(@Valid DmsCheckTemplateSaveReqVO createReqVO);

    /**
     * 更新点巡检模板
     *
     * @param updateReqVO 更新信息
     */
    void updateCheckTemplate(@Valid DmsCheckTemplateSaveReqVO updateReqVO);

    /**
     * 删除点巡检模板
     *
     * @param id 编号
     */
    void deleteCheckTemplate(Long id);

    /**
     * 获得点巡检模板
     *
     * @param id 编号
     * @return 点巡检模板
     */
    DmsCheckTemplateDO getCheckTemplate(Long id);

    /**
     * 获得点巡检模板分页
     *
     * @param pageReqVO 分页查询
     * @return 点巡检模板分页
     */
    PageResult<DmsCheckTemplateDO> getCheckTemplatePage(DmsCheckTemplatePageReqVO pageReqVO);

    /**
     * 获取巡检模板列表
     * @param pageReqVO
     * @return
     */
    List<DmsCheckTemplateDO> getCheckTemplateList(DmsCheckTemplatePageReqVO pageReqVO);

    // ==================== 子表（点巡检模板检查项） ====================

    /**
     * 获得点巡检模板检查项分页
     *
     * @param pageReqVO 分页查询
     * @return 点巡检模板检查项分页
     */
    PageResult<DmsCheckTemplateItemDO> getCheckTemplateItemPage(DmsCheckTemplateItemPageReqVO pageReqVO);

    /**
     * 创建点巡检模板检查项
     *
     * @param checkTemplateItem 创建信息
     * @return 编号
     */
    Long createCheckTemplateItem(@Valid DmsCheckTemplateItemDO checkTemplateItem);

    /**
     * 更新点巡检模板检查项
     *
     * @param checkTemplateItem 更新信息
     */
    void updateCheckTemplateItem(@Valid DmsCheckTemplateItemDO checkTemplateItem);

    /**
     * 删除点巡检模板检查项
     *
     * @param id 编号
     */
    void deleteCheckTemplateItem(Long id);

    /**
     * 获得点巡检模板检查项
     *
     * @param id 编号
     * @return 点巡检模板检查项
     */
    DmsCheckTemplateItemDO getCheckTemplateItem(Long id);

}