package cn.iocoder.yudao.module.dms.service.checktemplate;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplatePageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplate.vo.DmsCheckTemplateSaveReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemPageReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplate.DmsCheckTemplateDO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateitem.DmsCheckTemplateItemDO;
import cn.iocoder.yudao.module.dms.dal.pgsql.checktemplate.DmsCheckTemplateMapper;
import cn.iocoder.yudao.module.dms.dal.pgsql.checktemplateitem.DmsCheckTemplateItemMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.dms.enums.ErrorCodeConstants.CHECK_TEMPLATE_ITEM_NOT_EXISTS;
import static cn.iocoder.yudao.module.dms.enums.ErrorCodeConstants.CHECK_TEMPLATE_NOT_EXISTS;

/**
 * 点巡检模板 Service 实现类
 *
 * @author dzx
 */
@Service
@Validated
public class DmsCheckTemplateServiceImpl implements DmsCheckTemplateService {

    @Resource
    private DmsCheckTemplateMapper dmsCheckTemplateMapper;
    @Resource
    private DmsCheckTemplateItemMapper dmsCheckTemplateItemMapper;

    @Override
    public Long createCheckTemplate(DmsCheckTemplateSaveReqVO createReqVO) {
        // 插入
        DmsCheckTemplateDO checkTemplate = BeanUtils.toBean(createReqVO, DmsCheckTemplateDO.class);
        checkTemplate.setDeptId(SecurityFrameworkUtils.getLoginUserDeptId());
        dmsCheckTemplateMapper.insert(checkTemplate);
        // 返回
        return checkTemplate.getId();
    }

    @Override
    public void updateCheckTemplate(DmsCheckTemplateSaveReqVO updateReqVO) {
        // 校验存在
        validateCheckTemplateExists(updateReqVO.getId());
        // 更新
        DmsCheckTemplateDO updateObj = BeanUtils.toBean(updateReqVO, DmsCheckTemplateDO.class);
        dmsCheckTemplateMapper.updateById(updateObj);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteCheckTemplate(Long id) {
        // 校验存在
        validateCheckTemplateExists(id);
        // 删除
        dmsCheckTemplateMapper.deleteById(id);

        // 删除子表
        deleteCheckTemplateItemByCheckTemplateId(id);
    }

    private void validateCheckTemplateExists(Long id) {
        if (dmsCheckTemplateMapper.selectById(id) == null) {
            throw exception(CHECK_TEMPLATE_NOT_EXISTS);
        }
    }

    @Override
    public DmsCheckTemplateDO getCheckTemplate(Long id) {
        return dmsCheckTemplateMapper.selectById(id);
    }

    @Override
    public PageResult<DmsCheckTemplateDO> getCheckTemplatePage(DmsCheckTemplatePageReqVO pageReqVO) {
        return dmsCheckTemplateMapper.selectPage(pageReqVO);
    }

    @Override
    public List<DmsCheckTemplateDO> getCheckTemplateList(DmsCheckTemplatePageReqVO pageReqVO) {
        return dmsCheckTemplateMapper.selectList(pageReqVO);
    }

    // ==================== 子表（点巡检模板检查项） ====================

    @Override
    public PageResult<DmsCheckTemplateItemDO> getCheckTemplateItemPage(DmsCheckTemplateItemPageReqVO pageReqVO) {
        return dmsCheckTemplateItemMapper.selectPage(pageReqVO);
    }

    @Override
    public Long createCheckTemplateItem(DmsCheckTemplateItemDO checkTemplateItem) {
        dmsCheckTemplateItemMapper.insert(checkTemplateItem);
        return checkTemplateItem.getId();
    }

    @Override
    public void updateCheckTemplateItem(DmsCheckTemplateItemDO checkTemplateItem) {
        // 校验存在
        validateCheckTemplateItemExists(checkTemplateItem.getId());
        // 更新
        dmsCheckTemplateItemMapper.updateById(checkTemplateItem);
    }

    @Override
    public void deleteCheckTemplateItem(Long id) {
        // 校验存在
        validateCheckTemplateItemExists(id);
        // 删除
        dmsCheckTemplateItemMapper.deleteById(id);
    }

    @Override
    public DmsCheckTemplateItemDO getCheckTemplateItem(Long id) {
        return dmsCheckTemplateItemMapper.selectById(id);
    }

    private void validateCheckTemplateItemExists(Long id) {
        if (dmsCheckTemplateItemMapper.selectById(id) == null) {
            throw exception(CHECK_TEMPLATE_ITEM_NOT_EXISTS);
        }
    }

    private void deleteCheckTemplateItemByCheckTemplateId(Long checkTemplateId) {
        dmsCheckTemplateItemMapper.deleteByCheckTemplateId(checkTemplateId);
    }

}
