package cn.iocoder.yudao.module.dms.service.checktemplateitem;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.checktemplateitem.vo.DmsCheckTemplateItemSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.checktemplateitem.DmsCheckTemplateItemDO;
import cn.iocoder.yudao.module.dms.dal.pgsql.checktemplateitem.DmsCheckTemplateItemMapper;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.dms.enums.ErrorCodeConstants.CHECK_TEMPLATE_ITEM_NOT_EXISTS;

/**
 * 点巡检模板检查项 Service 实现类
 *
 * @author dzx
 */
@Service
@Validated
public class DmsCheckTemplateItemServiceImpl implements DmsCheckTemplateItemService {

    @Resource
    private DmsCheckTemplateItemMapper dmsCheckTemplateItemMapper;

    @Override
    public Long createCheckTemplateItem(DmsCheckTemplateItemSaveReqVO createReqVO) {
        // 插入
        DmsCheckTemplateItemDO checkTemplateItem = BeanUtils.toBean(createReqVO, DmsCheckTemplateItemDO.class);
        dmsCheckTemplateItemMapper.insert(checkTemplateItem);
        // 返回
        return checkTemplateItem.getId();
    }

    @Override
    public void updateCheckTemplateItem(DmsCheckTemplateItemSaveReqVO updateReqVO) {
        // 校验存在
        validateCheckTemplateItemExists(updateReqVO.getId());
        // 更新
        DmsCheckTemplateItemDO updateObj = BeanUtils.toBean(updateReqVO, DmsCheckTemplateItemDO.class);
        dmsCheckTemplateItemMapper.updateById(updateObj);
    }

    @Override
    public void deleteCheckTemplateItem(Long id) {
        // 校验存在
        validateCheckTemplateItemExists(id);
        // 删除
        dmsCheckTemplateItemMapper.deleteById(id);
    }

    private void validateCheckTemplateItemExists(Long id) {
        if (dmsCheckTemplateItemMapper.selectById(id) == null) {
            throw exception(CHECK_TEMPLATE_ITEM_NOT_EXISTS);
        }
    }

    @Override
    public DmsCheckTemplateItemDO getCheckTemplateItem(Long id) {
        return dmsCheckTemplateItemMapper.selectById(id);
    }

    @Override
    public PageResult<DmsCheckTemplateItemDO> getCheckTemplateItemPage(DmsCheckTemplateItemPageReqVO pageReqVO) {
        return dmsCheckTemplateItemMapper.selectPage(pageReqVO);
    }

}
