package cn.iocoder.yudao.module.dms.service.relationorg;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.dms.controller.admin.relationorg.vo.DmsRelationOrgPageReqVO;
import cn.iocoder.yudao.module.dms.controller.admin.relationorg.vo.DmsRelationOrgSaveReqVO;
import cn.iocoder.yudao.module.dms.dal.dataobject.relationorg.DmsRelationContractDO;
import cn.iocoder.yudao.module.dms.dal.dataobject.relationorg.DmsRelationOrgDO;

import javax.validation.Valid;
import java.util.List;

/**
 * 往来单位 Service 接口
 *
 * @author dzx
 */
public interface DmsRelationOrgService {

    /**
     * 创建往来单位
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createRelationOrg(@Valid DmsRelationOrgSaveReqVO createReqVO);

    /**
     * 更新往来单位
     *
     * @param updateReqVO 更新信息
     */
    void updateRelationOrg(@Valid DmsRelationOrgSaveReqVO updateReqVO);

    /**
     * 删除往来单位
     *
     * @param id 编号
     */
    void deleteRelationOrg(Long id);

    /**
     * 获得往来单位
     *
     * @param id 编号
     * @return 往来单位
     */
    DmsRelationOrgDO getRelationOrg(Long id);

    /**
     * 获得往来单位分页
     *
     * @param pageReqVO 分页查询
     * @return 往来单位分页
     */
    PageResult<DmsRelationOrgDO> getRelationOrgPage(DmsRelationOrgPageReqVO pageReqVO);

    /**
     * 获得往来单位精简列表
     *
     * @return 列表
     */
    List<DmsRelationOrgDO> getSimpleRelationOrgList();

    // ==================== 子表（往来单位联系人） ====================

    /**
     * 获得往来单位联系人分页
     *
     * @param pageReqVO 分页查询
     * @param orgId     来往单位ID
     * @return 往来单位联系人分页
     */
    PageResult<DmsRelationContractDO> getRelationContractPage(PageParam pageReqVO, Long orgId);

    /**
     * 创建往来单位联系人
     *
     * @param relationContract 创建信息
     * @return 编号
     */
    Long createRelationContract(@Valid DmsRelationContractDO relationContract);

    /**
     * 更新往来单位联系人
     *
     * @param relationContract 更新信息
     */
    void updateRelationContract(@Valid DmsRelationContractDO relationContract);

    /**
     * 删除往来单位联系人
     *
     * @param id 编号
     */
    void deleteRelationContract(Long id);

    /**
     * 获得往来单位联系人
     *
     * @param id 编号
     * @return 往来单位联系人
     */
    DmsRelationContractDO getRelationContract(Long id);
}
